@@ -24,3 +24,10 @@ OWNER_ACCESS = 50
 VISIBILITY_PRIVATE = 0
 VISIBILITY_INTERNAL = 10
 VISIBILITY_PUBLIC = 20
+
+NOTIFICATION_LEVEL_DISABLED = 'disabled'
+NOTIFICATION_LEVEL_PARTICIPATING = 'participating'
+NOTIFICATION_LEVEL_WATCH = 'watch'
+NOTIFICATION_LEVEL_GLOBAL = 'global'
+NOTIFICATION_LEVEL_MENTION = 'mention'
+NOTIFICATION_LEVEL_CUSTOM = 'custom'
