@@ -222,6 +222,8 @@ class GitlabObject(object):
                 value = getattr(self, attribute)
                 if isinstance(value, list):
                     value = ",".join(value)
+                if attribute == 'sudo':
+                    value = str(value)
                 data[attribute] = value
 
         data.update(extra_parameters)
@@ -1018,6 +1020,54 @@ class LicenseManager(BaseManager):
     obj_cls = License
 
 
+class Snippet(GitlabObject):
+    _url = '/snippets'
+    _constructorTypes = {'author': 'User'}
+    requiredCreateAttrs = ['title', 'file_name', 'content']
+    optionalCreateAttrs = ['lifetime', 'visibility_level']
+    optionalUpdateAttrs = ['title', 'file_name', 'content', 'visibility_level']
+    shortPrintAttr = 'title'
+
+    def raw(self, streamed=False, action=None, chunk_size=1024, **kwargs):
+        """Return the raw content of a snippet.
+
+        Args:
+            streamed (bool): If True the data will be processed by chunks of
+                `chunk_size` and each chunk is passed to `action` for
+                treatment.
+            action (callable): Callable responsible of dealing with chunk of
+                data.
+            chunk_size (int): Size of each chunk.
+
+        Returns:
+            str: The snippet content.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+            GitlabGetError: If the server fails to perform the request.
+        """
+        url = ("/snippets/%(snippet_id)s/raw" % {'snippet_id': self.id})
+        r = self.gitlab._raw_get(url, **kwargs)
+        raise_error_from_response(r, GitlabGetError)
+        return utils.response_content(r, streamed, action, chunk_size)
+
+
+class SnippetManager(BaseManager):
+    obj_cls = Snippet
+
+    def public(self, **kwargs):
+        """List all the public snippets.
+
+        Args:
+            all (bool): If True, return all the items, without pagination
+            **kwargs: Additional arguments to send to GitLab.
+
+        Returns:
+            list(gitlab.Gitlab.Snippet): The list of snippets.
+        """
+        return self.gitlab._raw_list("/snippets/public", Snippet, **kwargs)
+
+
 class Namespace(GitlabObject):
     _url = '/namespaces'
     canGet = 'from_list'
@@ -1992,8 +2042,16 @@ class ProjectService(GitlabObject):
                                   'server')),
         'irker': (('recipients', ), ('default_irc_uri', 'server_port',
                                      'server_host', 'colorize_messages')),
-        'jira': (('new_issue_url', 'project_url', 'issues_url'),
-                 ('api_url', 'description', 'username', 'password')),
+        'jira': (tuple(), (
+                 # Required fields in GitLab >= 8.14
+                 'url', 'project_key',
+
+                 # Required fields in GitLab < 8.14
+                 'new_issue_url', 'project_url', 'issues_url', 'api_url',
+                 'description',
+
+                 # Optional fields
+                 'username', 'password', 'jira_issue_transition_id')),
         'pivotaltracker': (('token', ), tuple()),
         'pushover': (('api_key', 'user_key', 'priority'), ('device', 'sound')),
         'redmine': (('new_issue_url', 'project_url', 'issues_url'),
@@ -2083,21 +2141,24 @@ class Project(GitlabObject):
     _url = '/projects'
     _constructorTypes = {'owner': 'User', 'namespace': 'Group'}
     requiredCreateAttrs = ['name']
-    optionalCreateAttrs = ['default_branch', 'issues_enabled', 'wall_enabled',
-                           'merge_requests_enabled', 'wiki_enabled',
+    optionalCreateAttrs = ['path', 'namespace_id', 'description',
+                           'issues_enabled', 'merge_requests_enabled',
+                           'builds_enabled', 'wiki_enabled',
                            'snippets_enabled', 'container_registry_enabled',
-                           'public', 'visibility_level', 'namespace_id',
-                           'description', 'path', 'import_url',
-                           'builds_enabled', 'public_builds',
-                           'only_allow_merge_if_build_succeeds']
-    optionalUpdateAttrs = ['name', 'default_branch', 'issues_enabled',
-                           'wall_enabled', 'merge_requests_enabled',
-                           'wiki_enabled', 'snippets_enabled',
-                           'container_registry_enabled', 'public',
-                           'visibility_level', 'namespace_id', 'description',
-                           'path', 'import_url', 'builds_enabled',
-                           'public_builds',
-                           'only_allow_merge_if_build_succeeds']
+                           'shared_runners_enabled', 'public',
+                           'visibility_level', 'import_url', 'public_builds',
+                           'only_allow_merge_if_build_succeeds',
+                           'only_allow_merge_if_all_discussions_are_resolved',
+                           'lfs_enabled', 'request_access_enabled']
+    optionalUpdateAttrs = ['name', 'path', 'default_branch', 'description',
+                           'issues_enabled', 'merge_requests_enabled',
+                           'builds_enabled', 'wiki_enabled',
+                           'snippets_enabled', 'container_registry_enabled',
+                           'shared_runners_enabled', 'public',
+                           'visibility_level', 'import_url', 'public_builds',
+                           'only_allow_merge_if_build_succeeds',
+                           'only_allow_merge_if_all_discussions_are_resolved',
+                           'lfs_enabled', 'request_access_enabled']
     shortPrintAttr = 'path'
     managers = (
         ('accessrequests', ProjectAccessRequestManager,
